diff --git a/application/views/system/infocenter/infocenter.php b/application/views/system/infocenter/infocenter.php
index 1ecfe31f7..ab9746a8e 100644
--- a/application/views/system/infocenter/infocenter.php
+++ b/application/views/system/infocenter/infocenter.php
@@ -9,8 +9,8 @@
'fontawesome' => true,
'sbadmintemplate' => true,
'tablesorter' => true,
- 'customCSSs' => 'skin/tablesort_bootstrap.css',
- 'customJSs' => array('include/js/bootstrapper.js', 'include/js/infocenter/infocenterPersonDataset.js')
+ 'customCSSs' => 'public/css/sbadmin2/tablesort_bootstrap.css',
+ 'customJSs' => array('public/js/bootstrapper.js', 'public/js/infocenter/infocenterPersonDataset.js')
)
);
?>
diff --git a/application/views/system/infocenter/infocenterDetails.php b/application/views/system/infocenter/infocenterDetails.php
index 147f5d981..7038031a0 100755
--- a/application/views/system/infocenter/infocenterDetails.php
+++ b/application/views/system/infocenter/infocenterDetails.php
@@ -13,14 +13,14 @@
'addons' => true,
'customCSSs' =>
array(
- 'skin/admintemplate.css',
- 'skin/tablesort_bootstrap.css'
+ 'public/css/sbadmin2/admintemplate.css',
+ 'public/css/sbadmin2/tablesort_bootstrap.css'
),
'customJSs' =>
array(
- 'include/js/bootstrapper.js',
- 'include/js/tablesort/tablesort.js',
- 'include/js/infocenter/infocenterDetails.js')
+ 'public/js/bootstrapper.js',
+ 'public/js/tablesort/tablesort.js',
+ 'public/js/infocenter/infocenterDetails.js')
)
);
?>
diff --git a/application/views/system/infocenter/infocenterFreigegeben.php b/application/views/system/infocenter/infocenterFreigegeben.php
index 66e5b5c8b..03da9b718 100644
--- a/application/views/system/infocenter/infocenterFreigegeben.php
+++ b/application/views/system/infocenter/infocenterFreigegeben.php
@@ -9,8 +9,8 @@
'fontawesome' => true,
'sbadmintemplate' => true,
'tablesorter' => true,
- 'customCSSs' => 'skin/tablesort_bootstrap.css',
- 'customJSs' => array('include/js/bootstrapper.js', 'include/js/infocenter/infocenterPersonDataset.js')
+ 'customCSSs' => 'public/css/sbadmin2/tablesort_bootstrap.css',
+ 'customJSs' => array('public/js/bootstrapper.js', 'public/js/infocenter/infocenterPersonDataset.js')
)
);
?>
diff --git a/application/views/system/messageWrite.php b/application/views/system/messageWrite.php
index 2b15cc12d..3f9ed5254 100644
--- a/application/views/system/messageWrite.php
+++ b/application/views/system/messageWrite.php
@@ -8,8 +8,8 @@ $this->load->view(
'fontawesome' => true,
'tinymce' => true,
'sbadmintemplate' => true,
- 'customCSSs' => 'skin/admintemplate_contentonly.css',
- 'customJSs' => 'include/js/bootstrapper.js'
+ 'customCSSs' => 'public/css/sbadmin2/admintemplate_contentonly.css',
+ 'customJSs' => 'public/js/bootstrapper.js'
)
);
?>
diff --git a/skin/admintemplate.css b/public/css/sbadmin2/admintemplate.css
similarity index 99%
rename from skin/admintemplate.css
rename to public/css/sbadmin2/admintemplate.css
index 5df64ce30..e47fdd3b2 100644
--- a/skin/admintemplate.css
+++ b/public/css/sbadmin2/admintemplate.css
@@ -30,7 +30,6 @@
/*float: right; */ /* adjust as needed */
margin: 15px;
color: grey; /* adjust as needed */
-
}
.panel-heading .accordion-toggle.collapsed:before{
diff --git a/skin/admintemplate_contentonly.css b/public/css/sbadmin2/admintemplate_contentonly.css
similarity index 100%
rename from skin/admintemplate_contentonly.css
rename to public/css/sbadmin2/admintemplate_contentonly.css
diff --git a/skin/tablesort_bootstrap.css b/public/css/sbadmin2/tablesort_bootstrap.css
similarity index 100%
rename from skin/tablesort_bootstrap.css
rename to public/css/sbadmin2/tablesort_bootstrap.css
diff --git a/include/js/bootstrapper.js b/public/js/bootstrapper.js
similarity index 100%
rename from include/js/bootstrapper.js
rename to public/js/bootstrapper.js
diff --git a/include/js/infocenter/infocenterDetails.js b/public/js/infocenter/infocenterDetails.js
similarity index 92%
rename from include/js/infocenter/infocenterDetails.js
rename to public/js/infocenter/infocenterDetails.js
index 0d409fe13..8373c7d4e 100644
--- a/include/js/infocenter/infocenterDetails.js
+++ b/public/js/infocenter/infocenterDetails.js
@@ -1,17 +1,3 @@
-/*
- This program is free software: you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program. If not, see .
- */
/**
* javascript file for infocenterDetails page
*/
diff --git a/include/js/infocenter/infocenterPersonDataset.js b/public/js/infocenter/infocenterPersonDataset.js
similarity index 85%
rename from include/js/infocenter/infocenterPersonDataset.js
rename to public/js/infocenter/infocenterPersonDataset.js
index 5cac8933a..7f99b6fc6 100644
--- a/include/js/infocenter/infocenterPersonDataset.js
+++ b/public/js/infocenter/infocenterPersonDataset.js
@@ -1,18 +1,3 @@
-/*
- This program is free software: you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program. If not, see .
-*/
-
/**
* Javascript file for infocenter overview page
*/
diff --git a/include/js/tablesort/tablesort.js b/public/js/tablesort/tablesort.js
similarity index 69%
rename from include/js/tablesort/tablesort.js
rename to public/js/tablesort/tablesort.js
index c1c171959..7ee70a002 100644
--- a/include/js/tablesort/tablesort.js
+++ b/public/js/tablesort/tablesort.js
@@ -1,22 +1,3 @@
-/*
- This program is free software: you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program. If not, see .
- */
-/**
- * provides helper functions for adding mottie tablesorter
- * enables easier configuration of the tablesorter by providing a common default configuration
- */
-
/**
* adds tablesorter to specified tableid, german date format, default theme
* @param tableid
diff --git a/application/models/organisation/Organisationseinheit_model.php b/application/models/organisation/Organisationseinheit_model.php
index 75791de1b..272204e7e 100644
--- a/application/models/organisation/Organisationseinheit_model.php
+++ b/application/models/organisation/Organisationseinheit_model.php
@@ -119,15 +119,16 @@ class Organisationseinheit_model extends DB_Model
/**
* Liefert die ChildNodes einer Organisationseinheit
* @param $oe_kurzbz
* @return Array mit den Childs inkl dem Uebergebenen Element
*/
- public function getChilds($oe_kurzbz)
+ public function getChilds($oe_kurzbz, $includeinactive = false)
{
$query = "
WITH RECURSIVE oes(oe_kurzbz, oe_parent_kurzbz) as
(
SELECT oe_kurzbz, oe_parent_kurzbz FROM public.tbl_organisationseinheit
- WHERE oe_kurzbz=?
+ WHERE oe_kurzbz=? %s
UNION ALL
SELECT o.oe_kurzbz, o.oe_parent_kurzbz FROM public.tbl_organisationseinheit o, oes
WHERE o.oe_parent_kurzbz=oes.oe_kurzbz
@@ -136,20 +137,22 @@ class Organisationseinheit_model extends DB_Model
FROM oes
GROUP BY oe_kurzbz;";
- return $this->execQuery($query, array($oe_kurzbz));
+ return $this->execQuery(sprintf($query, $includeinactive === true ? "" : "AND aktiv = true"), array($oe_kurzbz));
}
/**
* Liefert die OEs die im Tree ueberhalb der uebergebene OE liegen
* @param $oe_kurzbz
+ * @param bool $includeinactive - wether to include inactive parent oes
+ * @return array|null
*/
- public function getParents($oe_kurzbz)
+ public function getParents($oe_kurzbz, $includeinactive = false)
{
$query=
"WITH RECURSIVE oes(oe_kurzbz, oe_parent_kurzbz) as
(
SELECT oe_kurzbz, oe_parent_kurzbz FROM public.tbl_organisationseinheit
- WHERE oe_kurzbz=? and aktiv = true
+ WHERE oe_kurzbz=? %s
UNION ALL
SELECT o.oe_kurzbz, o.oe_parent_kurzbz FROM public.tbl_organisationseinheit o, oes
WHERE o.oe_kurzbz=oes.oe_parent_kurzbz and aktiv = true
@@ -157,7 +160,7 @@ class Organisationseinheit_model extends DB_Model
SELECT oe_kurzbz
FROM oes";
- return $this->execQuery($query, array($oe_kurzbz));
+ return $this->execQuery(sprintf($query, $includeinactive === true ? "" : "AND aktiv = true"), array($oe_kurzbz));
}
}
@@ -119,15 +119,16 @@ class Organisationseinheit_model extends DB_Model
* Liefert die ChildNodes einer Organisationseinheit
* @param $oe_kurzbz
- * @return Array mit den Childs inkl dem Uebergebenen Element
+ * @param bool $includeinactive - wether to include inactive parent oes
+ * @return array mit den Childs inkl dem Uebergebenen Element
*/